/* This is a GENERATED file. */
g_test_add_func("/testlibgwy/version", test_version);
g_test_add_func("/testlibgwy/str/memmem", test_str_memmem);
g_test_add_func("/testlibgwy/str/next-line", test_str_next_line);
g_test_add_func("/testlibgwy/str/isident/ascii", test_str_isident_ascii);
g_test_add_func("/testlibgwy/str/among", test_str_among);
g_test_add_func("/testlibgwy/str/kill", test_str_kill);
g_test_add_func("/testlibgwy/str/case-equal/ascii", test_str_case_equal_ascii);
g_test_add_func("/testlibgwy/str/case-hash/ascii", test_str_case_hash_ascii);
g_test_add_func("/testlibgwy/str/gstring-replace/null-old", test_str_gstring_replace_null_old);
g_test_add_func("/testlibgwy/str/gstring-replace/null-replacement", test_str_gstring_replace_null_replacement);
g_test_add_func("/testlibgwy/str/gstring-replace/general", test_str_gstring_replace_general);
g_test_add_func("/testlibgwy/str/assign/string", test_str_assign_string);
g_test_add_func("/testlibgwy/str/assign/gstring", test_str_assign_gstring);
g_test_add_func("/testlibgwy/str/utf8-strescape", test_str_utf8_strescape);
g_test_add_func("/testlibgwy/math/powi/one", test_math_powi_one);
g_test_add_func("/testlibgwy/math/powi/zero", test_math_powi_zero);
g_test_add_func("/testlibgwy/math/powi/basic", test_math_powi_basic);
g_test_add_func("/testlibgwy/math/deg2rad", test_math_deg2rad);
g_test_add_func("/testlibgwy/math/rad2deg", test_math_rad2deg);
g_test_add_func("/testlibgwy/math/mean", test_math_mean);
g_test_add_func("/testlibgwy/math/sort/double", test_math_sort_double);
g_test_add_func("/testlibgwy/math/trimmed-mean", test_math_trimmed_mean);
g_test_add_func("/testlibgwy/math/curvature/apex/straight", test_math_curvature_apex_straight);
g_test_add_func("/testlibgwy/math/curvature/apex/parabolic", test_math_curvature_apex_parabolic);
g_test_add_func("/testlibgwy/math/curvature/apex/askew", test_math_curvature_apex_askew);
g_test_add_func("/testlibgwy/math/is-in-polygon/square", test_math_is_in_polygon_square);
g_test_add_func("/testlibgwy/math/is-in-polygon/bowtie", test_math_is_in_polygon_bowtie);
g_test_add_func("/testlibgwy/math/refine-maximum/1d", test_math_refine_maximum_1d);
g_test_add_func("/testlibgwy/math/refine-maximum/2d", test_math_refine_maximum_2d);
g_test_add_func("/testlibgwy/math/accumulate-counts", test_math_accumulate_counts);
g_test_add_func("/testlibgwy/error-list/basic", test_error_list_basic);
g_test_add_func("/testlibgwy/error-list/propagation", test_error_list_propagation);
g_test_add_func("/testlibgwy/raw-data/size-consistency", test_raw_data_size_consistency);
g_test_add_func("/testlibgwy/raw-data/uint8/le/stride1", test_raw_data_uint8_le_stride1);
g_test_add_func("/testlibgwy/raw-data/uint8/be/stride1", test_raw_data_uint8_be_stride1);
g_test_add_func("/testlibgwy/raw-data/sint8/le/stride1", test_raw_data_sint8_le_stride1);
g_test_add_func("/testlibgwy/raw-data/sint8/be/stride1", test_raw_data_sint8_be_stride1);
g_test_add_func("/testlibgwy/raw-data/uint8/stride2", test_raw_data_uint8_stride2);
g_test_add_func("/testlibgwy/raw-data/uint8/stridem1", test_raw_data_uint8_stridem1);
g_test_add_func("/testlibgwy/raw-data/uint8/stride0", test_raw_data_uint8_stride0);
g_test_add_func("/testlibgwy/raw-data/uint4/be/stride1", test_raw_data_uint4_be_stride1);
g_test_add_func("/testlibgwy/raw-data/uint4/be/stride2", test_raw_data_uint4_be_stride2);
g_test_add_func("/testlibgwy/raw-data/uint4/be/stride3", test_raw_data_uint4_be_stride3);
g_test_add_func("/testlibgwy/raw-data/uint4/be/stridem1", test_raw_data_uint4_be_stridem1);
g_test_add_func("/testlibgwy/raw-data/uint4/be/stridem2", test_raw_data_uint4_be_stridem2);
g_test_add_func("/testlibgwy/raw-data/uint4/be/stride0", test_raw_data_uint4_be_stride0);
g_test_add_func("/testlibgwy/raw-data/sint4/be/stride1", test_raw_data_sint4_be_stride1);
g_test_add_func("/testlibgwy/raw-data/sint4/be/stride2", test_raw_data_sint4_be_stride2);
g_test_add_func("/testlibgwy/raw-data/sint4/be/stride3", test_raw_data_sint4_be_stride3);
g_test_add_func("/testlibgwy/raw-data/sint4/be/stridem1", test_raw_data_sint4_be_stridem1);
g_test_add_func("/testlibgwy/raw-data/sint4/be/stridem2", test_raw_data_sint4_be_stridem2);
g_test_add_func("/testlibgwy/raw-data/uint4/le/stride1", test_raw_data_uint4_le_stride1);
g_test_add_func("/testlibgwy/raw-data/uint4/le/stride2", test_raw_data_uint4_le_stride2);
g_test_add_func("/testlibgwy/raw-data/uint4/le/stride3", test_raw_data_uint4_le_stride3);
g_test_add_func("/testlibgwy/raw-data/uint4/le/stridem1", test_raw_data_uint4_le_stridem1);
g_test_add_func("/testlibgwy/raw-data/uint4/le/stridem2", test_raw_data_uint4_le_stridem2);
g_test_add_func("/testlibgwy/raw-data/uint4/le/stride0", test_raw_data_uint4_le_stride0);
g_test_add_func("/testlibgwy/raw-data/sint4/le/stride1", test_raw_data_sint4_le_stride1);
g_test_add_func("/testlibgwy/raw-data/sint4/le/stride2", test_raw_data_sint4_le_stride2);
g_test_add_func("/testlibgwy/raw-data/sint4/le/stride3", test_raw_data_sint4_le_stride3);
g_test_add_func("/testlibgwy/raw-data/sint4/le/stridem1", test_raw_data_sint4_le_stridem1);
g_test_add_func("/testlibgwy/raw-data/sint4/le/stridem2", test_raw_data_sint4_le_stridem2);
g_test_add_func("/testlibgwy/raw-data/bit/be/stride1", test_raw_data_bit_be_stride1);
g_test_add_func("/testlibgwy/raw-data/bit/be/stride2", test_raw_data_bit_be_stride2);
g_test_add_func("/testlibgwy/raw-data/bit/be/stridem1", test_raw_data_bit_be_stridem1);
g_test_add_func("/testlibgwy/raw-data/bit/le/stride1", test_raw_data_bit_le_stride1);
g_test_add_func("/testlibgwy/raw-data/bit/le/stride2", test_raw_data_bit_le_stride2);
g_test_add_func("/testlibgwy/raw-data/bit/le/stridem1", test_raw_data_bit_le_stridem1);
g_test_add_func("/testlibgwy/raw-data/bit/stride0", test_raw_data_bit_stride0);
g_test_add_func("/testlibgwy/raw-data/uint12/be/stride1", test_raw_data_uint12_be_stride1);
g_test_add_func("/testlibgwy/raw-data/uint12/be/stride2", test_raw_data_uint12_be_stride2);
g_test_add_func("/testlibgwy/raw-data/uint12/be/stride3", test_raw_data_uint12_be_stride3);
g_test_add_func("/testlibgwy/raw-data/uint12/be/stridem1", test_raw_data_uint12_be_stridem1);
g_test_add_func("/testlibgwy/raw-data/uint12/be/stridem2", test_raw_data_uint12_be_stridem2);
g_test_add_func("/testlibgwy/raw-data/uint12/be/stride0", test_raw_data_uint12_be_stride0);
g_test_add_func("/testlibgwy/raw-data/sint12/be/stride1", test_raw_data_sint12_be_stride1);
g_test_add_func("/testlibgwy/raw-data/sint12/be/stride2", test_raw_data_sint12_be_stride2);
g_test_add_func("/testlibgwy/raw-data/sint12/be/stride3", test_raw_data_sint12_be_stride3);
g_test_add_func("/testlibgwy/raw-data/sint12/be/stridem1", test_raw_data_sint12_be_stridem1);
g_test_add_func("/testlibgwy/raw-data/sint12/be/stridem2", test_raw_data_sint12_be_stridem2);
g_test_add_func("/testlibgwy/raw-data/uint16/be/stride1", test_raw_data_uint16_be_stride1);
g_test_add_func("/testlibgwy/raw-data/uint16/be/stride2", test_raw_data_uint16_be_stride2);
g_test_add_func("/testlibgwy/raw-data/uint16/be/stridem1", test_raw_data_uint16_be_stridem1);
g_test_add_func("/testlibgwy/raw-data/uint16/be/stride0", test_raw_data_uint16_be_stride0);
g_test_add_func("/testlibgwy/raw-data/uint16/le/stride1", test_raw_data_uint16_le_stride1);
g_test_add_func("/testlibgwy/raw-data/uint16/le/stride2", test_raw_data_uint16_le_stride2);
g_test_add_func("/testlibgwy/raw-data/uint16/le/stridem1", test_raw_data_uint16_le_stridem1);
g_test_add_func("/testlibgwy/raw-data/uint16/le/stride0", test_raw_data_uint16_le_stride0);
g_test_add_func("/testlibgwy/raw-data/sint16/be/stride1", test_raw_data_sint16_be_stride1);
g_test_add_func("/testlibgwy/raw-data/sint16/be/stride2", test_raw_data_sint16_be_stride2);
g_test_add_func("/testlibgwy/raw-data/sint16/be/stridem1", test_raw_data_sint16_be_stridem1);
g_test_add_func("/testlibgwy/raw-data/sint16/le/stride1", test_raw_data_sint16_le_stride1);
g_test_add_func("/testlibgwy/raw-data/sint16/le/stride2", test_raw_data_sint16_le_stride2);
g_test_add_func("/testlibgwy/raw-data/sint16/le/stridem1", test_raw_data_sint16_le_stridem1);
g_test_add_func("/testlibgwy/raw-data/uint24/be/stride1", test_raw_data_uint24_be_stride1);
g_test_add_func("/testlibgwy/raw-data/uint24/be/stride2", test_raw_data_uint24_be_stride2);
g_test_add_func("/testlibgwy/raw-data/uint24/be/stridem1", test_raw_data_uint24_be_stridem1);
g_test_add_func("/testlibgwy/raw-data/uint24/be/stride0", test_raw_data_uint24_be_stride0);
g_test_add_func("/testlibgwy/raw-data/uint24/le/stride1", test_raw_data_uint24_le_stride1);
g_test_add_func("/testlibgwy/raw-data/uint24/le/stride2", test_raw_data_uint24_le_stride2);
g_test_add_func("/testlibgwy/raw-data/uint24/le/stridem1", test_raw_data_uint24_le_stridem1);
g_test_add_func("/testlibgwy/raw-data/uint24/le/stride0", test_raw_data_uint24_le_stride0);
g_test_add_func("/testlibgwy/raw-data/sint24/be/stride1", test_raw_data_sint24_be_stride1);
g_test_add_func("/testlibgwy/raw-data/sint24/be/stride2", test_raw_data_sint24_be_stride2);
g_test_add_func("/testlibgwy/raw-data/sint24/be/stridem1", test_raw_data_sint24_be_stridem1);
g_test_add_func("/testlibgwy/raw-data/sint24/le/stride1", test_raw_data_sint24_le_stride1);
g_test_add_func("/testlibgwy/raw-data/sint24/le/stride2", test_raw_data_sint24_le_stride2);
g_test_add_func("/testlibgwy/raw-data/sint24/le/stridem1", test_raw_data_sint24_le_stridem1);
g_test_add_func("/testlibgwy/raw-data/uint32/be/stride1", test_raw_data_uint32_be_stride1);
g_test_add_func("/testlibgwy/raw-data/uint32/be/stride2", test_raw_data_uint32_be_stride2);
g_test_add_func("/testlibgwy/raw-data/uint32/be/stridem1", test_raw_data_uint32_be_stridem1);
g_test_add_func("/testlibgwy/raw-data/uint32/be/stride0", test_raw_data_uint32_be_stride0);
g_test_add_func("/testlibgwy/raw-data/uint32/le/stride1", test_raw_data_uint32_le_stride1);
g_test_add_func("/testlibgwy/raw-data/uint32/le/stride2", test_raw_data_uint32_le_stride2);
g_test_add_func("/testlibgwy/raw-data/uint32/le/stridem1", test_raw_data_uint32_le_stridem1);
g_test_add_func("/testlibgwy/raw-data/uint32/le/stride0", test_raw_data_uint32_le_stride0);
g_test_add_func("/testlibgwy/raw-data/sint32/be/stride1", test_raw_data_sint32_be_stride1);
g_test_add_func("/testlibgwy/raw-data/sint32/be/stride2", test_raw_data_sint32_be_stride2);
g_test_add_func("/testlibgwy/raw-data/sint32/be/stridem1", test_raw_data_sint32_be_stridem1);
g_test_add_func("/testlibgwy/raw-data/sint32/le/stride1", test_raw_data_sint32_le_stride1);
g_test_add_func("/testlibgwy/raw-data/sint32/le/stride2", test_raw_data_sint32_le_stride2);
g_test_add_func("/testlibgwy/raw-data/sint32/le/stridem1", test_raw_data_sint32_le_stridem1);
g_test_add_func("/testlibgwy/raw-data/uint64/be/stride1", test_raw_data_uint64_be_stride1);
g_test_add_func("/testlibgwy/raw-data/uint64/be/stride2", test_raw_data_uint64_be_stride2);
g_test_add_func("/testlibgwy/raw-data/uint64/be/stridem1", test_raw_data_uint64_be_stridem1);
g_test_add_func("/testlibgwy/raw-data/uint64/be/stride0", test_raw_data_uint64_be_stride0);
g_test_add_func("/testlibgwy/raw-data/uint64/le/stride1", test_raw_data_uint64_le_stride1);
g_test_add_func("/testlibgwy/raw-data/uint64/le/stride2", test_raw_data_uint64_le_stride2);
g_test_add_func("/testlibgwy/raw-data/uint64/le/stridem1", test_raw_data_uint64_le_stridem1);
g_test_add_func("/testlibgwy/raw-data/uint64/le/stride0", test_raw_data_uint64_le_stride0);
g_test_add_func("/testlibgwy/raw-data/sint64/be/stride1", test_raw_data_sint64_be_stride1);
g_test_add_func("/testlibgwy/raw-data/sint64/be/stride2", test_raw_data_sint64_be_stride2);
g_test_add_func("/testlibgwy/raw-data/sint64/be/stridem1", test_raw_data_sint64_be_stridem1);
g_test_add_func("/testlibgwy/raw-data/sint64/le/stride1", test_raw_data_sint64_le_stride1);
g_test_add_func("/testlibgwy/raw-data/sint64/le/stride2", test_raw_data_sint64_le_stride2);
g_test_add_func("/testlibgwy/raw-data/sint64/le/stridem1", test_raw_data_sint64_le_stridem1);
g_test_add_func("/testlibgwy/raw-data/half/be/stride1", test_raw_data_half_be_stride1);
g_test_add_func("/testlibgwy/raw-data/half/be/stride2", test_raw_data_half_be_stride2);
g_test_add_func("/testlibgwy/raw-data/half/be/stridem1", test_raw_data_half_be_stridem1);
g_test_add_func("/testlibgwy/raw-data/half/be/stride0", test_raw_data_half_be_stride0);
g_test_add_func("/testlibgwy/raw-data/half/le/stride1", test_raw_data_half_le_stride1);
g_test_add_func("/testlibgwy/raw-data/half/le/stride2", test_raw_data_half_le_stride2);
g_test_add_func("/testlibgwy/raw-data/half/le/stridem1", test_raw_data_half_le_stridem1);
g_test_add_func("/testlibgwy/raw-data/half/le/stride0", test_raw_data_half_le_stride0);
g_test_add_func("/testlibgwy/raw-data/pascal/be/stride1", test_raw_data_pascal_be_stride1);
g_test_add_func("/testlibgwy/raw-data/pascal/be/stride2", test_raw_data_pascal_be_stride2);
g_test_add_func("/testlibgwy/raw-data/pascal/be/stridem1", test_raw_data_pascal_be_stridem1);
g_test_add_func("/testlibgwy/raw-data/pascal/be/stride0", test_raw_data_pascal_be_stride0);
g_test_add_func("/testlibgwy/raw-data/pascal/le/stride1", test_raw_data_pascal_le_stride1);
g_test_add_func("/testlibgwy/raw-data/pascal/le/stride2", test_raw_data_pascal_le_stride2);
g_test_add_func("/testlibgwy/raw-data/pascal/le/stridem1", test_raw_data_pascal_le_stridem1);
g_test_add_func("/testlibgwy/raw-data/pascal/le/stride0", test_raw_data_pascal_le_stride0);
g_test_add_func("/testlibgwy/raw-data/extended/be/stride1", test_raw_data_extended_be_stride1);
g_test_add_func("/testlibgwy/raw-data/extended/be/stride2", test_raw_data_extended_be_stride2);
g_test_add_func("/testlibgwy/raw-data/extended/be/stridem1", test_raw_data_extended_be_stridem1);
g_test_add_func("/testlibgwy/raw-data/extended/be/stride0", test_raw_data_extended_be_stride0);
g_test_add_func("/testlibgwy/raw-data/extended/le/stride1", test_raw_data_extended_le_stride1);
g_test_add_func("/testlibgwy/raw-data/extended/le/stride2", test_raw_data_extended_le_stride2);
g_test_add_func("/testlibgwy/raw-data/extended/le/stridem1", test_raw_data_extended_le_stridem1);
g_test_add_func("/testlibgwy/serialization/append/int16", test_serialization_append_int16);
g_test_add_func("/testlibgwy/serialization/append/int32", test_serialization_append_int32);
g_test_add_func("/testlibgwy/serialization/append/int64", test_serialization_append_int64);
g_test_add_func("/testlibgwy/serialization/append/float", test_serialization_append_float);
g_test_add_func("/testlibgwy/serialization/append/double", test_serialization_append_double);
g_test_add_func("/testlibgwy/serialization/append/string", test_serialization_append_string);
g_test_add_func("/testlibgwy/serialization/append/unit", test_serialization_append_unit);
g_test_add_func("/testlibgwy/serialization/append/rgba", test_serialization_append_rgba);
g_test_add_func("/testlibgwy/serialization/append/int8-array", test_serialization_append_int8_array);
g_test_add_func("/testlibgwy/serialization/append/int16-array", test_serialization_append_int16_array);
g_test_add_func("/testlibgwy/serialization/append/int32-array", test_serialization_append_int32_array);
g_test_add_func("/testlibgwy/serialization/append/int64-array", test_serialization_append_int64_array);
g_test_add_func("/testlibgwy/serialization/append/float-array", test_serialization_append_float_array);
g_test_add_func("/testlibgwy/serialization/append/double-array", test_serialization_append_double_array);
g_test_add_func("/testlibgwy/serialization/append/string-array", test_serialization_append_string_array);
g_test_add_func("/testlibgwy/serialization/group/grow/one", test_serialization_group_grow_one);
g_test_add_func("/testlibgwy/serialization/group/grow/many", test_serialization_group_grow_many);
g_test_add_func("/testlibgwy/serialization/fill-pspec", test_serialization_fill_pspec);
g_test_add_func("/testlibgwy/serialization/filter-items/normal", test_serialization_filter_items_normal);
g_test_add_func("/testlibgwy/serialization/filter-items/repeating", test_serialization_filter_items_repeating);
g_test_add_func("/testlibgwy/serialization/filter-items/bad-type", test_serialization_filter_items_bad_type);
g_test_add_func("/testlibgwy/serialization/filter-items/pspec-good", test_serialization_filter_items_pspec_good);
g_test_add_func("/testlibgwy/serialization/filter-items/pspec-bad", test_serialization_filter_items_pspec_bad);
g_test_add_func("/testlibgwy/serialization/check-dimensions/0d", test_serialization_check_dimensions_0d);
g_test_add_func("/testlibgwy/serialization/check-dimensions/1d", test_serialization_check_dimensions_1d);
g_test_add_func("/testlibgwy/serialization/check-dimensions/2d", test_serialization_check_dimensions_2d);
g_test_add_func("/testlibgwy/serialization/check-dimensions/3d", test_serialization_check_dimensions_3d);
g_test_add_func("/testlibgwy/serialization/double-component/normal", test_serialization_double_component_normal);
g_test_add_func("/testlibgwy/serialization/double-component/infnan", test_serialization_double_component_infnan);
g_test_add_func("/testlibgwy/serialization/int32-component", test_serialization_int32_component);
g_test_add_func("/testlibgwy/serialization/enum-component", test_serialization_enum_component);
g_test_add_func("/testlibgwy/serialization/object-component/null", test_serialization_object_component_null);
g_test_add_func("/testlibgwy/serialization/object-component/single", test_serialization_object_component_single);
g_test_add_func("/testlibgwy/serialization/object-component/array", test_serialization_object_component_array);
g_test_add_func("/testlibgwy/serialization/trivial/native", test_serialization_trivial_native);
g_test_add_func("/testlibgwy/serialization/trivial/32bit", test_serialization_trivial_32bit);
g_test_add_func("/testlibgwy/serialization/trivial/64bit", test_serialization_trivial_64bit);
g_test_add_func("/testlibgwy/serialization/less-trivial/native", test_serialization_less_trivial_native);
g_test_add_func("/testlibgwy/serialization/less-trivial/32bit", test_serialization_less_trivial_32bit);
g_test_add_func("/testlibgwy/serialization/less-trivial/64bit", test_serialization_less_trivial_64bit);
g_test_add_func("/testlibgwy/serialization/nested/native", test_serialization_nested_native);
g_test_add_func("/testlibgwy/serialization/nested/32bit", test_serialization_nested_32bit);
g_test_add_func("/testlibgwy/serialization/nested/64bit", test_serialization_nested_64bit);
g_test_add_func("/testlibgwy/serialization/extra-item", test_serialization_extra_item);
g_test_add_func("/testlibgwy/serialization/write-error", test_serialization_write_error);
g_test_add_func("/testlibgwy/serialization/fuzz/native", test_serialization_fuzz_native);
g_test_add_func("/testlibgwy/serialization/fuzz/32bit", test_serialization_fuzz_32bit);
g_test_add_func("/testlibgwy/serialization/fuzz/64bit", test_serialization_fuzz_64bit);
g_test_add_func("/testlibgwy/string-list/append", test_string_list_append);
g_test_add_func("/testlibgwy/string-list/assign", test_string_list_assign);
g_test_add_func("/testlibgwy/string-list/copy", test_string_list_copy);
g_test_add_func("/testlibgwy/string-list/serialize-simple", test_string_list_serialize_simple);
g_test_add_func("/testlibgwy/unit/parse/power", test_unit_parse_power);
g_test_add_func("/testlibgwy/unit/parse/power10", test_unit_parse_power10);
g_test_add_func("/testlibgwy/unit/parse/meter", test_unit_parse_meter);
g_test_add_func("/testlibgwy/unit/parse/micro", test_unit_parse_micro);
g_test_add_func("/testlibgwy/unit/parse/combine", test_unit_parse_combine);
g_test_add_func("/testlibgwy/unit/parse/confusing-like-prefix", test_unit_parse_confusing_like_prefix);
g_test_add_func("/testlibgwy/unit/parse/confusing-with-prefix", test_unit_parse_confusing_with_prefix);
g_test_add_func("/testlibgwy/unit/word-names/simple", test_unit_word_names_simple);
g_test_add_func("/testlibgwy/unit/word-names/unknown", test_unit_word_names_unknown);
g_test_add_func("/testlibgwy/unit/word-names/prefixed", test_unit_word_names_prefixed);
g_test_add_func("/testlibgwy/unit/arithmetic/simple", test_unit_arithmetic_simple);
g_test_add_func("/testlibgwy/unit/arithmetic/commutativity", test_unit_arithmetic_commutativity);
g_test_add_func("/testlibgwy/unit/arithmetic/nth-root", test_unit_arithmetic_nth_root);
g_test_add_func("/testlibgwy/unit/serialize/simple", test_unit_serialize_simple);
g_test_add_func("/testlibgwy/unit/serialize/random", test_unit_serialize_random);
g_test_add_func("/testlibgwy/unit/assign", test_unit_assign);
g_test_add_func("/testlibgwy/unit/copy", test_unit_copy);
g_test_add_func("/testlibgwy/unit/garbage", test_unit_garbage);
g_test_add_func("/testlibgwy/dict/in-construction", test_dict_in_construction);
g_test_add_func("/testlibgwy/dict/data/boolean", test_dict_data_boolean);
g_test_add_func("/testlibgwy/dict/data/int32", test_dict_data_int32);
g_test_add_func("/testlibgwy/dict/data/int64", test_dict_data_int64);
g_test_add_func("/testlibgwy/dict/data/double", test_dict_data_double);
g_test_add_func("/testlibgwy/dict/data/string", test_dict_data_string);
g_test_add_func("/testlibgwy/dict/gvalue", test_dict_gvalue);
g_test_add_func("/testlibgwy/dict/notify/boolean", test_dict_notify_boolean);
g_test_add_func("/testlibgwy/dict/notify/int32", test_dict_notify_int32);
g_test_add_func("/testlibgwy/dict/notify/string", test_dict_notify_string);
g_test_add_func("/testlibgwy/dict/notify/object", test_dict_notify_object);
g_test_add_func("/testlibgwy/dict/notify/boxed", test_dict_notify_boxed);
g_test_add_func("/testlibgwy/dict/prefix", test_dict_prefix);
g_test_add_func("/testlibgwy/dict/transfer/object/default", test_dict_transfer_object_default);
g_test_add_func("/testlibgwy/dict/transfer/object/force", test_dict_transfer_object_force);
g_test_add_func("/testlibgwy/dict/transfer/object/deep", test_dict_transfer_object_deep);
g_test_add_func("/testlibgwy/dict/refcount", test_dict_refcount);
g_test_add_func("/testlibgwy/dict/keys", test_dict_keys);
g_test_add_func("/testlibgwy/dict/copy", test_dict_copy);
g_test_add_func("/testlibgwy/dict/assign", test_dict_assign);
g_test_add_func("/testlibgwy/dict/serialize/simple", test_dict_serialize_simple);
g_test_add_func("/testlibgwy/dict/serialize/nested", test_dict_serialize_nested);
g_test_add_func("/testlibgwy/dict/serialize/text", test_dict_serialize_text);
g_test_add_func("/testlibgwy/xy/boxed/serialization", test_xy_boxed_serialization);
g_test_add_func("/testlibgwy/xy/boxed/equal", test_xy_boxed_equal);
g_test_add_func("/testlibgwy/xy/boxed/assign", test_xy_boxed_assign);
g_test_add_func("/testlibgwy/xyz/boxed/serialization", test_xyz_boxed_serialization);
g_test_add_func("/testlibgwy/xyz/boxed/equal", test_xyz_boxed_equal);
g_test_add_func("/testlibgwy/xyz/boxed/assign", test_xyz_boxed_assign);
g_test_add_func("/testlibgwy/rgba/boxed/serialization", test_rgba_boxed_serialization);
g_test_add_func("/testlibgwy/rgba/boxed/equal", test_rgba_boxed_equal);
g_test_add_func("/testlibgwy/rgba/boxed/assign", test_rgba_boxed_assign);
g_test_add_func("/testlibgwy/rgba/interpolation", test_rgba_interpolation);
g_test_add_func("/testlibgwy/rgba/pixbuf-pixel/to", test_rgba_pixbuf_pixel_to);
g_test_add_func("/testlibgwy/rgba/pixbuf-pixel/from", test_rgba_pixbuf_pixel_from);
g_test_add_func("/testlibgwy/inventory/data/name", test_inventory_data_name);
g_test_add_func("/testlibgwy/inventory/data/nth", test_inventory_data_nth);
g_test_add_func("/testlibgwy/inventory/default", test_inventory_default);
g_test_add_func("/testlibgwy/inventory/sorting", test_inventory_sorting);
g_test_add_func("/testlibgwy/inventory/functional", test_inventory_functional);
g_test_add_func("/testlibgwy/resource/default", test_resource_default);
g_test_add_func("/testlibgwy/resource/create-new", test_resource_create_new);
g_test_add_func("/testlibgwy/resource/dump-parse", test_resource_dump_parse);
g_test_add_func("/testlibgwy/gradient/edit", test_gradient_edit);
g_test_add_func("/testlibgwy/gradient/inventory", test_gradient_inventory);
g_test_add_func("/testlibgwy/gradient/serialization", test_gradient_serialization);
g_test_add_func("/testlibgwy/gradient/copy", test_gradient_copy);
g_test_add_func("/testlibgwy/gradient/assign", test_gradient_assign);
g_test_add_func("/testlibgwy/gradient/get-color", test_gradient_get_color);
g_test_add_func("/testlibgwy/gradient/sample", test_gradient_sample);
g_test_add_func("/testlibgwy/gl-material/edit", test_gl_material_edit);
g_test_add_func("/testlibgwy/gl-material/serialization", test_gl_material_serialization);
g_test_add_func("/testlibgwy/gl-material/copy", test_gl_material_copy);
g_test_add_func("/testlibgwy/gl-material/assign", test_gl_material_assign);
g_test_add_func("/testlibgwy/line/basic", test_line_basic);
g_test_add_func("/testlibgwy/line/data-changed", test_line_data_changed);
g_test_add_func("/testlibgwy/line/serialization", test_line_serialization);
g_test_add_func("/testlibgwy/line/copy", test_line_copy);
g_test_add_func("/testlibgwy/line/assign", test_line_assign);
g_test_add_func("/testlibgwy/line/resize", test_line_resize);
g_test_add_func("/testlibgwy/line/part-extract", test_line_part_extract);
g_test_add_func("/testlibgwy/line/crop", test_line_crop);
g_test_add_func("/testlibgwy/line/part-copy", test_line_part_copy);
g_test_add_func("/testlibgwy/line/flip", test_line_flip);
g_test_add_func("/testlibgwy/line/clear/part", test_line_clear_part);
g_test_add_func("/testlibgwy/line/fill/part", test_line_fill_part);
g_test_add_func("/testlibgwy/line/compatibility/res", test_line_compatibility_res);
g_test_add_func("/testlibgwy/line/compatibility/real", test_line_compatibility_real);
g_test_add_func("/testlibgwy/line/compatibility/lateral", test_line_compatibility_lateral);
g_test_add_func("/testlibgwy/line/compatibility/value", test_line_compatibility_value);
g_test_add_func("/testlibgwy/line/compatibility/measure", test_line_compatibility_measure);
g_test_add_func("/testlibgwy/line/compatibility/mixed", test_line_compatibility_mixed);
g_test_add_func("/testlibgwy/line/extend/border", test_line_extend_border);
g_test_add_func("/testlibgwy/line/extend/mirror", test_line_extend_mirror);
g_test_add_func("/testlibgwy/line/extend/periodic", test_line_extend_periodic);
g_test_add_func("/testlibgwy/line/extend/fixed", test_line_extend_fixed);
g_test_add_func("/testlibgwy/line/extend/laplace", test_line_extend_laplace);
g_test_add_func("/testlibgwy/line/extend/connect", test_line_extend_connect);
g_test_add_func("/testlibgwy/line/extend/undefined", test_line_extend_undefined);
g_test_add_func("/testlibgwy/line/cumulate/plain", test_line_cumulate_plain);
g_test_add_func("/testlibgwy/line/cumulate/to-cdist", test_line_cumulate_to_cdist);
g_test_add_func("/testlibgwy/line/line-level", test_line_line_level);
g_test_add_func("/testlibgwy/line/fit-line/random", test_line_fit_line_random);
g_test_add_func("/testlibgwy/line/fit-line/degenerate", test_line_fit_line_degenerate);
g_test_add_func("/testlibgwy/line/stats/avg/linear", test_line_stats_avg_linear);
g_test_add_func("/testlibgwy/line/stats/sum/linear", test_line_stats_sum_linear);
g_test_add_func("/testlibgwy/line/stats/min/linear", test_line_stats_min_linear);
g_test_add_func("/testlibgwy/line/stats/max/linear", test_line_stats_max_linear);
g_test_add_func("/testlibgwy/line/stats/rms/linear", test_line_stats_rms_linear);
g_test_add_func("/testlibgwy/line/stats/skew/linear", test_line_stats_skew_linear);
g_test_add_func("/testlibgwy/line/stats/kurtosis/linear", test_line_stats_kurtosis_linear);
g_test_add_func("/testlibgwy/line/stats/variation/linear", test_line_stats_variation_linear);
g_test_add_func("/testlibgwy/line/stats/tan-beta0/linear", test_line_stats_tan_beta0_linear);
g_test_add_func("/testlibgwy/line/stats/length/linear", test_line_stats_length_linear);
g_test_add_func("/testlibgwy/line/peaks/count/peaks", test_line_peaks_count_peaks);
g_test_add_func("/testlibgwy/line/peaks/count/valleys", test_line_peaks_count_valleys);
g_test_add_func("/testlibgwy/line/peaks/kth/peaks/basic", test_line_peaks_kth_peaks_basic);
g_test_add_func("/testlibgwy/line/peaks/kth/peaks/average", test_line_peaks_kth_peaks_average);
g_test_add_func("/testlibgwy/line/peaks/kth/peaks/too-few", test_line_peaks_kth_peaks_too_few);
g_test_add_func("/testlibgwy/line/peaks/kth/peaks/none", test_line_peaks_kth_peaks_none);
g_test_add_func("/testlibgwy/line/peaks/kth/valleys/basic", test_line_peaks_kth_valleys_basic);
g_test_add_func("/testlibgwy/line/peaks/kth/valleys/average", test_line_peaks_kth_valleys_average);
g_test_add_func("/testlibgwy/line/peaks/kth/valleys/too-few", test_line_peaks_kth_valleys_too_few);
g_test_add_func("/testlibgwy/line/peaks/kth/valleys/none", test_line_peaks_kth_valleys_none);
g_test_add_func("/testlibgwy/line/laplace-solve", test_line_laplace_solve);
g_test_add_func("/testlibgwy/field/basic", test_field_basic);
g_test_add_func("/testlibgwy/field/invalidate", test_field_invalidate);
g_test_add_func("/testlibgwy/field/data-changed", test_field_data_changed);
g_test_add_func("/testlibgwy/field/serialization", test_field_serialization);
g_test_add_func("/testlibgwy/field/copy", test_field_copy);
g_test_add_func("/testlibgwy/field/assign", test_field_assign);
g_test_add_func("/testlibgwy/field/setval", test_field_setval);
g_test_add_func("/testlibgwy/field/compatibility/res", test_field_compatibility_res);
g_test_add_func("/testlibgwy/field/compatibility/real", test_field_compatibility_real);
g_test_add_func("/testlibgwy/field/compatibility/lateral", test_field_compatibility_lateral);
g_test_add_func("/testlibgwy/field/compatibility/value", test_field_compatibility_value);
g_test_add_func("/testlibgwy/field/compatibility/measure", test_field_compatibility_measure);
g_test_add_func("/testlibgwy/field/compatibility/mixed", test_field_compatibility_mixed);
g_test_add_func("/testlibgwy/field/resize", test_field_resize);
g_test_add_func("/testlibgwy/field/area-extract", test_field_area_extract);
g_test_add_func("/testlibgwy/field/crop", test_field_crop);
g_test_add_func("/testlibgwy/field/area-copy", test_field_area_copy);
g_test_add_func("/testlibgwy/field/flip/x", test_field_flip_x);
g_test_add_func("/testlibgwy/field/flip/y", test_field_flip_y);
g_test_add_func("/testlibgwy/field/flip/xy", test_field_flip_xy);
g_test_add_func("/testlibgwy/field/transpose/major", test_field_transpose_major);
g_test_add_func("/testlibgwy/field/transpose/minor", test_field_transpose_minor);
g_test_add_func("/testlibgwy/field/clear/area", test_field_clear_area);
g_test_add_func("/testlibgwy/field/fill/area", test_field_fill_area);
g_test_add_func("/testlibgwy/field/fill/area-mask", test_field_fill_area_mask);
g_test_add_func("/testlibgwy/field/fill/mask-01", test_field_fill_mask_01);
g_test_add_func("/testlibgwy/field/extend/border", test_field_extend_border);
g_test_add_func("/testlibgwy/field/extend/mirror", test_field_extend_mirror);
g_test_add_func("/testlibgwy/field/extend/periodic", test_field_extend_periodic);
g_test_add_func("/testlibgwy/field/extend/fixed", test_field_extend_fixed);
g_test_add_func("/testlibgwy/field/extend/laplace", test_field_extend_laplace);
g_test_add_func("/testlibgwy/field/extend/connect", test_field_extend_connect);
g_test_add_func("/testlibgwy/field/extend/undefined", test_field_extend_undefined);
g_test_add_func("/testlibgwy/field/plane-level", test_field_plane_level);
g_test_add_func("/testlibgwy/field/fit-plane/random", test_field_fit_plane_random);
g_test_add_func("/testlibgwy/field/fit-plane/degenerate", test_field_fit_plane_degenerate);
g_test_add_func("/testlibgwy/field/fit-plane/area/basic", test_field_fit_plane_area_basic);
g_test_add_func("/testlibgwy/field/fit-plane/area/degenerate/2x2", test_field_fit_plane_area_degenerate_2x2);
g_test_add_func("/testlibgwy/field/fit-poly/linear", test_field_fit_poly_linear);
g_test_add_func("/testlibgwy/field/fit-poly/masked", test_field_fit_poly_masked);
g_test_add_func("/testlibgwy/field/stats/avg/planar", test_field_stats_avg_planar);
g_test_add_func("/testlibgwy/field/stats/avg/bilinear", test_field_stats_avg_bilinear);
g_test_add_func("/testlibgwy/field/stats/avg/area", test_field_stats_avg_area);
g_test_add_func("/testlibgwy/field/stats/avg/masked", test_field_stats_avg_masked);
g_test_add_func("/testlibgwy/field/stats/median/full", test_field_stats_median_full);
g_test_add_func("/testlibgwy/field/stats/median/area", test_field_stats_median_area);
g_test_add_func("/testlibgwy/field/stats/median/masked", test_field_stats_median_masked);
g_test_add_func("/testlibgwy/field/stats/min/planar", test_field_stats_min_planar);
g_test_add_func("/testlibgwy/field/stats/min/area", test_field_stats_min_area);
g_test_add_func("/testlibgwy/field/stats/min/masked", test_field_stats_min_masked);
g_test_add_func("/testlibgwy/field/stats/max/planar", test_field_stats_max_planar);
g_test_add_func("/testlibgwy/field/stats/max/area", test_field_stats_max_area);
g_test_add_func("/testlibgwy/field/stats/max/masked", test_field_stats_max_masked);
g_test_add_func("/testlibgwy/field/stats/min-max/area", test_field_stats_min_max_area);
g_test_add_func("/testlibgwy/field/stats/min-max/masked", test_field_stats_min_max_masked);
g_test_add_func("/testlibgwy/field/stats/sum/planar", test_field_stats_sum_planar);
g_test_add_func("/testlibgwy/field/stats/sum/bilinear", test_field_stats_sum_bilinear);
g_test_add_func("/testlibgwy/field/stats/sum/area", test_field_stats_sum_area);
g_test_add_func("/testlibgwy/field/stats/sum/masked", test_field_stats_sum_masked);
g_test_add_func("/testlibgwy/field/stats/mean-square/planar", test_field_stats_mean_square_planar);
g_test_add_func("/testlibgwy/field/stats/mean-square/bilinear", test_field_stats_mean_square_bilinear);
g_test_add_func("/testlibgwy/field/stats/mean-square/area", test_field_stats_mean_square_area);
g_test_add_func("/testlibgwy/field/stats/mean-square/masked", test_field_stats_mean_square_masked);
g_test_add_func("/testlibgwy/field/stats/rms/planar", test_field_stats_rms_planar);
g_test_add_func("/testlibgwy/field/stats/rms/bilinear", test_field_stats_rms_bilinear);
g_test_add_func("/testlibgwy/field/stats/rms/area", test_field_stats_rms_area);
g_test_add_func("/testlibgwy/field/stats/rms/masked", test_field_stats_rms_masked);
g_test_add_func("/testlibgwy/field/stats/stats/planar", test_field_stats_stats_planar);
g_test_add_func("/testlibgwy/field/stats/stats/bilinear", test_field_stats_stats_bilinear);
g_test_add_func("/testlibgwy/field/stats/stats/area", test_field_stats_stats_area);
g_test_add_func("/testlibgwy/field/stats/area/square", test_field_stats_area_square);
g_test_add_func("/testlibgwy/field/stats/area/nonsquare", test_field_stats_area_nonsquare);
g_test_add_func("/testlibgwy/field/stats/variation/square", test_field_stats_variation_square);
g_test_add_func("/testlibgwy/field/stats/variation/nonsquare", test_field_stats_variation_nonsquare);
g_test_add_func("/testlibgwy/field/stats/volume/constant", test_field_stats_volume_constant);
g_test_add_func("/testlibgwy/field/stats/volume/planar", test_field_stats_volume_planar);
g_test_add_func("/testlibgwy/field/stats/height-dist/full", test_field_stats_height_dist_full);
g_test_add_func("/testlibgwy/field/stats/height-dist/area", test_field_stats_height_dist_area);
g_test_add_func("/testlibgwy/field/stats/height-dist/masked", test_field_stats_height_dist_masked);
g_test_add_func("/testlibgwy/field/stats/minkowski/black/auto", test_field_stats_minkowski_black_auto);
g_test_add_func("/testlibgwy/field/stats/minkowski/white/auto", test_field_stats_minkowski_white_auto);
g_test_add_func("/testlibgwy/field/stats/minkowski/connectivity/auto", test_field_stats_minkowski_connectivity_auto);
g_test_add_func("/testlibgwy/field/line-stats/rows/mean", test_field_line_stats_rows_mean);
g_test_add_func("/testlibgwy/field/line-stats/columns/mean", test_field_line_stats_columns_mean);
g_test_add_func("/testlibgwy/field/filter/square/minimum", test_field_filter_square_minimum);
g_test_add_func("/testlibgwy/field/filter/square/maximum", test_field_filter_square_maximum);
g_test_add_func("/testlibgwy/field/filter/minmax/minimum", test_field_filter_minmax_minimum);
g_test_add_func("/testlibgwy/field/filter/minmax/maximum", test_field_filter_minmax_maximum);
g_test_add_func("/testlibgwy/field/filter/minmax/range", test_field_filter_minmax_range);
g_test_add_func("/testlibgwy/field/filter/minmax/normalization", test_field_filter_minmax_normalization);
g_test_add_func("/testlibgwy/field/filter/minmax/dilation", test_field_filter_minmax_dilation);
g_test_add_func("/testlibgwy/field/filter/minmax/frosion", test_field_filter_minmax_frosion);
g_test_add_func("/testlibgwy/field/filter/rank", test_field_filter_rank);
g_test_add_func("/testlibgwy/field/filter/trimmed-mean", test_field_filter_trimmed_mean);
g_test_add_func("/testlibgwy/field/local-maximum/subpixel", test_field_local_maximum_subpixel);
g_test_add_func("/testlibgwy/field/local-maximum/search", test_field_local_maximum_search);
g_test_add_func("/testlibgwy/field/local-maximum/edge", test_field_local_maximum_edge);
g_test_add_func("/testlibgwy/field/local-maximum/stripe", test_field_local_maximum_stripe);
g_test_add_func("/testlibgwy/field/laplace-solve/scattered", test_field_laplace_solve_scattered);
g_test_add_func("/testlibgwy/field/laplace-solve/numbered", test_field_laplace_solve_numbered);
g_test_add_func("/testlibgwy/field/laplace-solve/masked", test_field_laplace_solve_masked);
g_test_add_func("/testlibgwy/field/laplace-solve/unmasked", test_field_laplace_solve_unmasked);
g_test_add_func("/testlibgwy/field/laplace-solve/all-grains", test_field_laplace_solve_all_grains);
g_test_add_func("/testlibgwy/field/tip/dilation", test_field_tip_dilation);
g_test_add_func("/testlibgwy/field/tip/erosion/spike", test_field_tip_erosion_spike);
g_test_add_func("/testlibgwy/field/tip/blind-estimate", test_field_tip_blind_estimate);
g_test_add_func("/testlibgwy/nield/basic", test_nield_basic);
g_test_add_func("/testlibgwy/nield/data-changed", test_nield_data_changed);
g_test_add_func("/testlibgwy/nield/serialization", test_nield_serialization);
g_test_add_func("/testlibgwy/nield/copy", test_nield_copy);
g_test_add_func("/testlibgwy/nield/assign", test_nield_assign);
g_test_add_func("/testlibgwy/nield/resize", test_nield_resize);
g_test_add_func("/testlibgwy/nield/area-extract", test_nield_area_extract);
g_test_add_func("/testlibgwy/nield/crop", test_nield_crop);
g_test_add_func("/testlibgwy/nield/area-copy", test_nield_area_copy);
g_test_add_func("/testlibgwy/nield/flip/x", test_nield_flip_x);
g_test_add_func("/testlibgwy/nield/flip/y", test_nield_flip_y);
g_test_add_func("/testlibgwy/nield/flip/xy", test_nield_flip_xy);
g_test_add_func("/testlibgwy/nield/transpose/major", test_nield_transpose_major);
g_test_add_func("/testlibgwy/nield/transpose/minor", test_nield_transpose_minor);
g_test_add_func("/testlibgwy/nield/grain/number-contiguous/simple", test_nield_grain_number_contiguous_simple);
g_test_add_func("/testlibgwy/nield/grain/number-contiguous/spiral", test_nield_grain_number_contiguous_spiral);
g_test_add_func("/testlibgwy/nield/grain/number-contiguous/negative", test_nield_grain_number_contiguous_negative);
g_test_add_func("/testlibgwy/nield/grain/clear-at", test_nield_grain_clear_at);
g_test_add_func("/testlibgwy/nield/grain/isolate/reconstruction", test_nield_grain_isolate_reconstruction);
g_test_add_func("/testlibgwy/nield/grain/isolate/bbox", test_nield_grain_isolate_bbox);
g_test_add_func("/testlibgwy/nield/grain/isolate-at/reconstruction", test_nield_grain_isolate_at_reconstruction);
g_test_add_func("/testlibgwy/nield/grain/isolate-at/bbox", test_nield_grain_isolate_at_bbox);
g_test_add_func("/testlibgwy/nield/compatibility/res", test_nield_compatibility_res);
g_test_add_func("/testlibgwy/nield/count/full", test_nield_count_full);
g_test_add_func("/testlibgwy/nield/count/area", test_nield_count_area);
g_test_add_func("/testlibgwy/nield/count/masked", test_nield_count_masked);
g_test_add_func("/testlibgwy/nield/distance-transform/conn4/merged/noborder", test_nield_distance_transform_conn4_merged_noborder);
g_test_add_func("/testlibgwy/nield/distance-transform/conn4/merged/border", test_nield_distance_transform_conn4_merged_border);
g_test_add_func("/testlibgwy/nield/distance-transform/conn8/merged/noborder", test_nield_distance_transform_conn8_merged_noborder);
g_test_add_func("/testlibgwy/nield/distance-transform/conn8/merged/border", test_nield_distance_transform_conn8_merged_border);
g_test_add_func("/testlibgwy/nield/distance-transform/octagonal48/merged/noborder", test_nield_distance_transform_octagonal48_merged_noborder);
g_test_add_func("/testlibgwy/nield/distance-transform/octagonal48/merged/border", test_nield_distance_transform_octagonal48_merged_border);
g_test_add_func("/testlibgwy/nield/distance-transform/octagonal84/merged/noborder", test_nield_distance_transform_octagonal84_merged_noborder);
g_test_add_func("/testlibgwy/nield/distance-transform/octagonal84/merged/border", test_nield_distance_transform_octagonal84_merged_border);
g_test_add_func("/testlibgwy/nield/distance-transform/octagonal/merged/noborder", test_nield_distance_transform_octagonal_merged_noborder);
g_test_add_func("/testlibgwy/nield/distance-transform/octagonal/merged/border", test_nield_distance_transform_octagonal_merged_border);
g_test_add_func("/testlibgwy/nield/distance-transform/euclidean/merged/noborder", test_nield_distance_transform_euclidean_merged_noborder);
g_test_add_func("/testlibgwy/nield/distance-transform/euclidean/merged/border", test_nield_distance_transform_euclidean_merged_border);
g_test_add_func("/testlibgwy/nield/distance-transform/conn4/split/noborder", test_nield_distance_transform_conn4_split_noborder);
g_test_add_func("/testlibgwy/nield/distance-transform/conn4/split/border", test_nield_distance_transform_conn4_split_border);
g_test_add_func("/testlibgwy/nield/distance-transform/conn8/split/noborder", test_nield_distance_transform_conn8_split_noborder);
g_test_add_func("/testlibgwy/nield/distance-transform/conn8/split/border", test_nield_distance_transform_conn8_split_border);
g_test_add_func("/testlibgwy/nield/distance-transform/octagonal48/split/noborder", test_nield_distance_transform_octagonal48_split_noborder);
g_test_add_func("/testlibgwy/nield/distance-transform/octagonal48/split/border", test_nield_distance_transform_octagonal48_split_border);
g_test_add_func("/testlibgwy/nield/distance-transform/octagonal84/split/noborder", test_nield_distance_transform_octagonal84_split_noborder);
g_test_add_func("/testlibgwy/nield/distance-transform/octagonal84/split/border", test_nield_distance_transform_octagonal84_split_border);
g_test_add_func("/testlibgwy/nield/distance-transform/octagonal/split/noborder", test_nield_distance_transform_octagonal_split_noborder);
g_test_add_func("/testlibgwy/nield/distance-transform/octagonal/split/border", test_nield_distance_transform_octagonal_split_border);
g_test_add_func("/testlibgwy/nield/distance-transform/euclidean/split/noborder", test_nield_distance_transform_euclidean_split_noborder);
g_test_add_func("/testlibgwy/nield/distance-transform/euclidean/split/border", test_nield_distance_transform_euclidean_split_border);
g_test_add_func("/testlibgwy/nield/resample/down", test_nield_resample_down);
g_test_add_func("/testlibgwy/nield/resample/up", test_nield_resample_up);
g_test_add_func("/testlibgwy/nield/extend/border", test_nield_extend_border);
g_test_add_func("/testlibgwy/nield/extend/mirror", test_nield_extend_mirror);
g_test_add_func("/testlibgwy/nield/extend/periodic", test_nield_extend_periodic);
g_test_add_func("/testlibgwy/nield/extend/fixed", test_nield_extend_fixed);
g_test_add_func("/testlibgwy/nield/extend/undefined", test_nield_extend_undefined);
g_test_add_func("/testlibgwy/nield/grain/sizes", test_nield_grain_sizes);
g_test_add_func("/testlibgwy/nield/grain/bounding-boxes", test_nield_grain_bounding_boxes);
g_test_add_func("/testlibgwy/nield/grain/bounding-boxes-periodic", test_nield_grain_bounding_boxes_periodic);
g_test_add_func("/testlibgwy/nield/grain/inscribed-boxes", test_nield_grain_inscribed_boxes);
g_test_add_func("/testlibgwy/nield/grain/fill-voids/simple", test_nield_grain_fill_voids_simple);
g_test_add_func("/testlibgwy/nield/grain/fill-voids/nonsimple", test_nield_grain_fill_voids_nonsimple);
g_test_add_func("/testlibgwy/nield/grain/fill-voids/unchanged", test_nield_grain_fill_voids_unchanged);
g_test_add_func("/testlibgwy/nield/clear-touching-border/touching", test_nield_clear_touching_border_touching);
g_test_add_func("/testlibgwy/nield/clear-touching-border/completely", test_nield_clear_touching_border_completely);
g_test_add_func("/testlibgwy/nield/autocrop/normal", test_nield_autocrop_normal);
g_test_add_func("/testlibgwy/nield/autocrop/empty", test_nield_autocrop_empty);
g_test_add_func("/testlibgwy/nield/filter/minmax/minimum", test_nield_filter_minmax_minimum);
g_test_add_func("/testlibgwy/nield/filter/minmax/maximum", test_nield_filter_minmax_maximum);
g_test_add_func("/testlibgwy/nield/filter/minmax/range", test_nield_filter_minmax_range);
g_test_add_func("/testlibgwy/nield/filter/minmax/dilation", test_nield_filter_minmax_dilation);
g_test_add_func("/testlibgwy/nield/filter/minmax/frosion", test_nield_filter_minmax_frosion);
g_test_add_func("/testlibgwy/nield/boundary-pixels/border", test_nield_boundary_pixels_border);
g_test_add_func("/testlibgwy/nield/boundary-pixels/noborder", test_nield_boundary_pixels_noborder);
g_test_add_func("/testlibgwy/nield/convex-hull/tightness", test_nield_convex_hull_tightness);
g_test_add_func("/testlibgwy/nield/convex-hull/convexity", test_nield_convex_hull_convexity);
g_test_add_func("/testlibgwy/nield/convex-hull/coverage", test_nield_convex_hull_coverage);
g_test_add_func("/testlibgwy/nield/mark-range/inclusive", test_nield_mark_range_inclusive);
g_test_add_func("/testlibgwy/nield/mark-range/exclusive", test_nield_mark_range_exclusive);
g_test_add_func("/testlibgwy/nield/mark-by-threshold/above", test_nield_mark_by_threshold_above);
g_test_add_func("/testlibgwy/nield/mark-by-threshold/below", test_nield_mark_by_threshold_below);
g_test_add_func("/testlibgwy/nield/merge/clear", test_nield_merge_clear);
g_test_add_func("/testlibgwy/nield/merge/fill", test_nield_merge_fill);
g_test_add_func("/testlibgwy/nield/merge/min", test_nield_merge_min);
g_test_add_func("/testlibgwy/nield/merge/max", test_nield_merge_max);
g_test_add_func("/testlibgwy/nield/merge/keep", test_nield_merge_keep);
g_test_add_func("/testlibgwy/nield/merge/copy", test_nield_merge_copy);
g_test_add_func("/testlibgwy/nield/merge/subtract", test_nield_merge_subtract);
g_test_add_func("/testlibgwy/nield/merge/revsubtract", test_nield_merge_revsubtract);
g_test_add_func("/testlibgwy/nield/merge/xor", test_nield_merge_xor);
g_test_add_func("/testlibgwy/nield/merge/equal", test_nield_merge_equal);
g_test_add_func("/testlibgwy/nield/merge/outside", test_nield_merge_outside);
g_test_add_func("/testlibgwy/nield/merge/not", test_nield_merge_not);
g_test_add_func("/testlibgwy/nield/merge/ncopy", test_nield_merge_ncopy);
g_test_add_func("/testlibgwy/nield/merge/nor", test_nield_merge_nor);
g_test_add_func("/testlibgwy/nield/merge/nand", test_nield_merge_nand);
g_test_add_func("/testlibgwy/nield/merge/implies", test_nield_merge_implies);
g_test_add_func("/testlibgwy/nield/merge/converse", test_nield_merge_converse);
g_test_add_func("/testlibgwy/nield/grain-quantity/pixel-area", test_nield_grain_quantity_pixel_area);
g_test_add_func("/testlibgwy/nield/grain-quantity/projected-area", test_nield_grain_quantity_projected_area);
g_test_add_func("/testlibgwy/nield/grain-quantity/equiv-disc-radius", test_nield_grain_quantity_equiv_disc_radius);
g_test_add_func("/testlibgwy/nield/grain-quantity/maximum", test_nield_grain_quantity_maximum);
g_test_add_func("/testlibgwy/nield/grain-quantity/minimum", test_nield_grain_quantity_minimum);
g_test_add_func("/testlibgwy/nield/grain-quantity/mean", test_nield_grain_quantity_mean);
g_test_add_func("/testlibgwy/nield/grain-quantity/rms", test_nield_grain_quantity_rms);
g_test_add_func("/testlibgwy/nield/grain-quantity/median", test_nield_grain_quantity_median);
g_test_add_func("/testlibgwy/nield/grain-quantity/surface-area", test_nield_grain_quantity_surface_area);
g_test_add_func("/testlibgwy/nield/grain-quantity/center-x", test_nield_grain_quantity_center_x);
g_test_add_func("/testlibgwy/nield/grain-quantity/center-y", test_nield_grain_quantity_center_y);
g_test_add_func("/testlibgwy/nield/grain-quantity/slope-theta", test_nield_grain_quantity_slope_theta);
g_test_add_func("/testlibgwy/nield/grain-quantity/slope-phi", test_nield_grain_quantity_slope_phi);
g_test_add_func("/testlibgwy/nield/grain-quantity/volume-0", test_nield_grain_quantity_volume_0);
g_test_add_func("/testlibgwy/nield/grain-quantity/volume-min", test_nield_grain_quantity_volume_min);
g_test_add_func("/testlibgwy/nield/grain-quantity/volume-laplace", test_nield_grain_quantity_volume_laplace);
g_test_add_func("/testlibgwy/nield/grain-quantity/half-height-area", test_nield_grain_quantity_half_height_area);
g_test_add_func("/testlibgwy/nield/grain-quantity/boundary-minimum", test_nield_grain_quantity_boundary_minimum);
g_test_add_func("/testlibgwy/nield/grain-quantity/boundary-maximum", test_nield_grain_quantity_boundary_maximum);
g_test_add_func("/testlibgwy/nield/grain-quantity/maximum-project-size", test_nield_grain_quantity_maximum_project_size);
g_test_add_func("/testlibgwy/nield/grain-quantity/maximum-project-angle", test_nield_grain_quantity_maximum_project_angle);
g_test_add_func("/testlibgwy/nield/grain-quantity/minimum-project-size", test_nield_grain_quantity_minimum_project_size);
g_test_add_func("/testlibgwy/nield/grain-quantity/minimum-project-angle", test_nield_grain_quantity_minimum_project_angle);
g_test_add_func("/testlibgwy/nield/grain-quantity/equiv-ellipse", test_nield_grain_quantity_equiv_ellipse);
g_test_add_func("/testlibgwy/nield/grain-quantity/boundary-length", test_nield_grain_quantity_boundary_length);
g_test_add_func("/testlibgwy/nield/grain-quantity/convex-hull-area", test_nield_grain_quantity_convex_hull_area);
g_test_add_func("/testlibgwy/nield/grain-quantity/circumcircle-r", test_nield_grain_quantity_circumcircle_r);
g_test_add_func("/testlibgwy/nield/grain-quantity/circumcircle-x", test_nield_grain_quantity_circumcircle_x);
g_test_add_func("/testlibgwy/nield/grain-quantity/circumcircle-y", test_nield_grain_quantity_circumcircle_y);
g_test_add_func("/testlibgwy/shaped/elliptic/nield/fill/tall1", test_shaped_elliptic_nield_fill_tall1);
g_test_add_func("/testlibgwy/shaped/elliptic/nield/fill/flat1", test_shaped_elliptic_nield_fill_flat1);
g_test_add_func("/testlibgwy/shaped/elliptic/nield/fill/tall2", test_shaped_elliptic_nield_fill_tall2);
g_test_add_func("/testlibgwy/shaped/elliptic/nield/fill/flat2", test_shaped_elliptic_nield_fill_flat2);
g_test_add_func("/testlibgwy/shaped/elliptic/field/fill/tall1", test_shaped_elliptic_field_fill_tall1);
g_test_add_func("/testlibgwy/shaped/elliptic/field/fill/flat1", test_shaped_elliptic_field_fill_flat1);
g_test_add_func("/testlibgwy/shaped/elliptic/field/fill/tall2", test_shaped_elliptic_field_fill_tall2);
g_test_add_func("/testlibgwy/shaped/elliptic/field/fill/flat2", test_shaped_elliptic_field_fill_flat2);
g_test_add_func("/testlibgwy/shaped/elliptic/nield/fill/small", test_shaped_elliptic_nield_fill_small);
g_test_add_func("/testlibgwy/shaped/elliptic/field/fill/small", test_shaped_elliptic_field_fill_small);
g_test_add_func("/testlibgwy/shaped/elliptic/nield/fill/xysym", test_shaped_elliptic_nield_fill_xysym);
g_test_add_func("/testlibgwy/shaped/elliptic/field/fill/xysym", test_shaped_elliptic_field_fill_xysym);
g_test_add_func("/testlibgwy/shaped/elliptic/nield/fill/intersect", test_shaped_elliptic_nield_fill_intersect);
g_test_add_func("/testlibgwy/shaped/elliptic/field/fill/intersect", test_shaped_elliptic_field_fill_intersect);
g_test_add_func("/testlibgwy/shaped/elliptic/nield/extract/data", test_shaped_elliptic_nield_extract_data);
g_test_add_func("/testlibgwy/shaped/elliptic/nield/extract/coords", test_shaped_elliptic_nield_extract_coords);
g_test_add_func("/testlibgwy/shaped/elliptic/field/extract/data", test_shaped_elliptic_field_extract_data);
g_test_add_func("/testlibgwy/shaped/elliptic/field/extract/coords", test_shaped_elliptic_field_extract_coords);
g_test_add_func("/testlibgwy/shaped/circular/nield/fill/small", test_shaped_circular_nield_fill_small);
g_test_add_func("/testlibgwy/shaped/circular/field/fill/small", test_shaped_circular_field_fill_small);
g_test_add_func("/testlibgwy/shaped/circular/nield/fill/intersect", test_shaped_circular_nield_fill_intersect);
g_test_add_func("/testlibgwy/shaped/circular/field/fill/intersect", test_shaped_circular_field_fill_intersect);
g_test_add_func("/testlibgwy/shaped/circular/nield/extract/data", test_shaped_circular_nield_extract_data);
g_test_add_func("/testlibgwy/shaped/circular/nield/extract/coords", test_shaped_circular_nield_extract_coords);
g_test_add_func("/testlibgwy/shaped/circular/field/extract/data", test_shaped_circular_field_extract_data);
g_test_add_func("/testlibgwy/shaped/circular/field/extract/coords", test_shaped_circular_field_extract_coords);
g_test_add_func("/testlibgwy/shaped/linear8/nield/fill/small", test_shaped_linear8_nield_fill_small);
g_test_add_func("/testlibgwy/shaped/linear8/nield/fill/connected", test_shaped_linear8_nield_fill_connected);
g_test_add_func("/testlibgwy/shaped/linear8/nield/fill/xysym", test_shaped_linear8_nield_fill_xysym);
g_test_add_func("/testlibgwy/shaped/linear8/nield/fill/signsym", test_shaped_linear8_nield_fill_signsym);
g_test_add_func("/testlibgwy/shaped/linear8/nield/fill/intersect", test_shaped_linear8_nield_fill_intersect);
g_test_add_func("/testlibgwy/shaped/linear8/nield/extract/data", test_shaped_linear8_nield_extract_data);
g_test_add_func("/testlibgwy/shaped/linear8/nield/extract/coords", test_shaped_linear8_nield_extract_coords);
g_test_add_func("/testlibgwy/shaped/linear4/nield/fill/small", test_shaped_linear4_nield_fill_small);
g_test_add_func("/testlibgwy/shaped/linear4/nield/fill/connected", test_shaped_linear4_nield_fill_connected);
g_test_add_func("/testlibgwy/shaped/linear4/nield/fill/superset", test_shaped_linear4_nield_fill_superset);
g_test_add_func("/testlibgwy/shaped/linear4/nield/fill/xysym", test_shaped_linear4_nield_fill_xysym);
g_test_add_func("/testlibgwy/shaped/linear4/nield/fill/signsym", test_shaped_linear4_nield_fill_signsym);
g_test_add_func("/testlibgwy/shaped/linear4/nield/fill/intersect", test_shaped_linear4_nield_fill_intersect);
g_test_add_func("/testlibgwy/shaped/linear4/nield/extract/data", test_shaped_linear4_nield_extract_data);
g_test_add_func("/testlibgwy/shaped/linear4/nield/extract/coords", test_shaped_linear4_nield_extract_coords);
g_test_add_func("/testlibgwy/brick/basic", test_brick_basic);
g_test_add_func("/testlibgwy/brick/data-changed", test_brick_data_changed);
g_test_add_func("/testlibgwy/brick/serialization", test_brick_serialization);
g_test_add_func("/testlibgwy/brick/copy", test_brick_copy);
g_test_add_func("/testlibgwy/brick/assign", test_brick_assign);
g_test_add_func("/testlibgwy/brick/compatibility/res", test_brick_compatibility_res);
g_test_add_func("/testlibgwy/brick/compatibility/real", test_brick_compatibility_real);
g_test_add_func("/testlibgwy/brick/compatibility/lateral", test_brick_compatibility_lateral);
g_test_add_func("/testlibgwy/brick/compatibility/value", test_brick_compatibility_value);
g_test_add_func("/testlibgwy/brick/compatibility/measure", test_brick_compatibility_measure);
g_test_add_func("/testlibgwy/brick/compatibility/axiscal", test_brick_compatibility_axiscal);
g_test_add_func("/testlibgwy/brick/compatibility/mixed", test_brick_compatibility_mixed);
g_test_add_func("/testlibgwy/surface/basic", test_surface_basic);
g_test_add_func("/testlibgwy/surface/data-changed", test_surface_data_changed);
g_test_add_func("/testlibgwy/surface/serialization", test_surface_serialization);
g_test_add_func("/testlibgwy/surface/copy", test_surface_copy);
g_test_add_func("/testlibgwy/surface/assign", test_surface_assign);
g_test_add_func("/testlibgwy/spectra/basic", test_spectra_basic);
g_test_add_func("/testlibgwy/spectra/curves", test_spectra_curves);
g_test_add_func("/testlibgwy/spectra/serialization", test_spectra_serialization);
g_test_add_func("/testlibgwy/spectra/copy", test_spectra_copy);
g_test_add_func("/testlibgwy/spectra/assign", test_spectra_assign);
g_test_add_func("/testlibgwy/lawn/basic", test_lawn_basic);
g_test_add_func("/testlibgwy/lawn/curve-data", test_lawn_curve_data);
g_test_add_func("/testlibgwy/lawn/serialization", test_lawn_serialization);
g_test_add_func("/testlibgwy/lawn/copy", test_lawn_copy);
g_test_add_func("/testlibgwy/lawn/assign", test_lawn_assign);
g_test_add_func("/testlibgwy/selection/axis/basic", test_selection_axis_basic);
g_test_add_func("/testlibgwy/selection/axis/serialization", test_selection_axis_serialization);
g_test_add_func("/testlibgwy/selection/axis/copy", test_selection_axis_copy);
g_test_add_func("/testlibgwy/selection/axis/assign", test_selection_axis_assign);
g_test_add_func("/testlibgwy/selection/ellipse/basic", test_selection_ellipse_basic);
g_test_add_func("/testlibgwy/selection/ellipse/serialization", test_selection_ellipse_serialization);
g_test_add_func("/testlibgwy/selection/ellipse/copy", test_selection_ellipse_copy);
g_test_add_func("/testlibgwy/selection/ellipse/assign", test_selection_ellipse_assign);
g_test_add_func("/testlibgwy/selection/lattice/basic", test_selection_lattice_basic);
g_test_add_func("/testlibgwy/selection/lattice/serialization", test_selection_lattice_serialization);
g_test_add_func("/testlibgwy/selection/lattice/copy", test_selection_lattice_copy);
g_test_add_func("/testlibgwy/selection/lattice/assign", test_selection_lattice_assign);
g_test_add_func("/testlibgwy/selection/line/basic", test_selection_line_basic);
g_test_add_func("/testlibgwy/selection/line/serialization", test_selection_line_serialization);
g_test_add_func("/testlibgwy/selection/line/copy", test_selection_line_copy);
g_test_add_func("/testlibgwy/selection/line/assign", test_selection_line_assign);
g_test_add_func("/testlibgwy/selection/path/basic", test_selection_path_basic);
g_test_add_func("/testlibgwy/selection/path/serialization", test_selection_path_serialization);
g_test_add_func("/testlibgwy/selection/path/copy", test_selection_path_copy);
g_test_add_func("/testlibgwy/selection/path/assign", test_selection_path_assign);
g_test_add_func("/testlibgwy/selection/point/basic", test_selection_point_basic);
g_test_add_func("/testlibgwy/selection/point/serialization", test_selection_point_serialization);
g_test_add_func("/testlibgwy/selection/point/copy", test_selection_point_copy);
g_test_add_func("/testlibgwy/selection/point/assign", test_selection_point_assign);
g_test_add_func("/testlibgwy/selection/quad/basic", test_selection_quad_basic);
g_test_add_func("/testlibgwy/selection/quad/serialization", test_selection_quad_serialization);
g_test_add_func("/testlibgwy/selection/quad/copy", test_selection_quad_copy);
g_test_add_func("/testlibgwy/selection/quad/assign", test_selection_quad_assign);
g_test_add_func("/testlibgwy/selection/rectangle/basic", test_selection_rectangle_basic);
g_test_add_func("/testlibgwy/selection/rectangle/serialization", test_selection_rectangle_serialization);
g_test_add_func("/testlibgwy/selection/rectangle/copy", test_selection_rectangle_copy);
g_test_add_func("/testlibgwy/selection/rectangle/assign", test_selection_rectangle_assign);
g_test_add_func("/testlibgwy/selection/get-changed-object", test_selection_get_changed_object);
g_test_add_func("/testlibgwy/curve-model/basic", test_curve_model_basic);
g_test_add_func("/testlibgwy/curve-model/data", test_curve_model_data);
g_test_add_func("/testlibgwy/curve-model/serialization", test_curve_model_serialization);
g_test_add_func("/testlibgwy/curve-model/copy", test_curve_model_copy);
g_test_add_func("/testlibgwy/curve-model/assign", test_curve_model_assign);
g_test_add_func("/testlibgwy/graph-model/basic", test_graph_model_basic);
g_test_add_func("/testlibgwy/graph-model/serialization", test_graph_model_serialization);
g_test_add_func("/testlibgwy/graph-model/copy", test_graph_model_copy);
g_test_add_func("/testlibgwy/graph-model/assign", test_graph_model_assign);
g_test_add_func("/testlibgwy/module-utils/get/gboolean8", test_module_utils_get_gboolean8);
g_test_add_func("/testlibgwy/module-utils/get/guint16-be", test_module_utils_get_guint16_be);
g_test_add_func("/testlibgwy/module-utils/get/guint16-le", test_module_utils_get_guint16_le);
g_test_add_func("/testlibgwy/module-utils/get/gint16-be", test_module_utils_get_gint16_be);
g_test_add_func("/testlibgwy/module-utils/get/gint16-le", test_module_utils_get_gint16_le);
g_test_add_func("/testlibgwy/module-utils/get/guint32-be", test_module_utils_get_guint32_be);
g_test_add_func("/testlibgwy/module-utils/get/guint32-le", test_module_utils_get_guint32_le);
g_test_add_func("/testlibgwy/module-utils/get/gint32-be", test_module_utils_get_gint32_be);
g_test_add_func("/testlibgwy/module-utils/get/gint32-le", test_module_utils_get_gint32_le);
g_test_add_func("/testlibgwy/module-utils/get/guint64-be", test_module_utils_get_guint64_be);
g_test_add_func("/testlibgwy/module-utils/get/guint64-le", test_module_utils_get_guint64_le);
g_test_add_func("/testlibgwy/module-utils/get/gint64-be", test_module_utils_get_gint64_be);
g_test_add_func("/testlibgwy/module-utils/get/gint64-le", test_module_utils_get_gint64_le);
g_test_add_func("/testlibgwy/module-utils/get/gfloat-be", test_module_utils_get_gfloat_be);
g_test_add_func("/testlibgwy/module-utils/get/gfloat-le", test_module_utils_get_gfloat_le);
g_test_add_func("/testlibgwy/module-utils/get/gdouble-be", test_module_utils_get_gdouble_be);
g_test_add_func("/testlibgwy/module-utils/get/gdouble-le", test_module_utils_get_gdouble_le);
g_test_add_func("/testlibgwy/module-utils/get/pascal-real-be", test_module_utils_get_pascal_real_be);
g_test_add_func("/testlibgwy/module-utils/get/pascal-real-le", test_module_utils_get_pascal_real_le);
g_test_add_func("/testlibgwy/module-utils/nonsquare-image", test_module_utils_nonsquare_image);
g_test_add_func("/testlibgwy/module-utils/image-remove-bad/bad", test_module_utils_image_remove_bad_bad);
g_test_add_func("/testlibgwy/module-utils/image-remove-bad/nobad", test_module_utils_image_remove_bad_nobad);
g_test_add_func("/testlibgwy/module-utils/mask-nans", test_module_utils_mask_nans);
g_test_add_func("/testlibgwy/file/in-construction", test_file_in_construction);
g_test_add_func("/testlibgwy/file/ids", test_file_ids);
g_test_add_func("/testlibgwy/file/parse-key", test_file_parse_key);
g_test_add_func("/testlibgwy/file/serialization", test_file_serialization);
g_test_add_func("/testlibgwy/file/copy", test_file_copy);
g_test_add_func("/testlibgwy/file/assign", test_file_assign);
g_test_add_func("/testlibgwy/file/set-link", test_file_set_link);
g_test_add_func("/testlibgwy/file/set-title/image", test_file_set_title_image);
g_test_add_func("/testlibgwy/file/set-title/graph", test_file_set_title_graph);
g_test_add_func("/testlibgwy/file/set-title/volume", test_file_set_title_volume);
g_test_add_func("/testlibgwy/file/set-title/xyz", test_file_set_title_xyz);
g_test_add_func("/testlibgwy/file/set-title/cmap", test_file_set_title_cmap);
g_test_add_func("/testlibgwy/file/key/image", test_file_key_image);
g_test_add_func("/testlibgwy/file/key/graph", test_file_key_graph);
g_test_add_func("/testlibgwy/file/key/volume", test_file_key_volume);
g_test_add_func("/testlibgwy/file/key/xyz", test_file_key_xyz);
g_test_add_func("/testlibgwy/file/key/cmap", test_file_key_cmap);
g_test_add_func("/testlibgwy/file/sync-items/image/nodelete", test_file_sync_items_image_nodelete);
g_test_add_func("/testlibgwy/file/sync-items/image/delete", test_file_sync_items_image_delete);
g_test_add_func("/testlibgwy/file/copy-data/image", test_file_copy_data_image);
g_test_add_func("/testlibgwy/file/remove/image", test_file_remove_image);
